@@ -16,6 +16,8 @@ LineTableHeader = namedtuple('LineTableHeader', 'file_entry')
 
 TAG_reverse = dict((v, k) for k, v in ENUM_DW_TAG.items())
 ENUM_DW_AT['DW_AT_virtual'] = 0x30 # Once they fix and publish, remove this
+ENUM_DW_AT['DW_AT_program'] = 0x23
+ENUM_DW_AT['DW_AT_private'] = 0x24
 ATTR_reverse = dict((v, k) for k, v in ENUM_DW_AT.items())
 FORM_reverse = dict((v, k) for k, v in ENUM_DW_FORM.items())
 
